@@ -1,7 +1,7 @@
-def not_allowed():
+def not_allowed(*args):
     return "", 405
 
-def preflight():
+def preflight(*args):
     return "", 204, {
         "Access-Control-Allow-Origin": "*",
         "Access-Control-Allow-Methods": "GET",
